Tutorial on Kubeflow and TorchTrainer class
===========================================

.. include:: ../../../tutorials/distributed-ml/torch-kubeflow-1/README.md
   :parser: myst_parser.sphinx_


train-cpu.py
++++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-kubeflow-1/train-cpu.py
   :language: python


cpu.yaml
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-kubeflow-1/cpu.yaml
   :language: yaml

Dockerfile
++++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-kubeflow-1/Dockerfile
   :language: dockerfile
